Learn R Programming

dsdp (version 0.1.1)

igammac: Complementary Incomplete Gamma Function

Description

Evaluate an complementary incomplete gamma function: $$\gamma^{*}(a, x) = \int_{x}^{\infty} t^{a-1} e^{-t}dt,$$ using SLATEC dgamic in https://netlib.org/slatec/. When (\(x > 0\) and \(a \ge 0\)) or (\(x \ge 0\) and \(a > 0\)), compute the result, otherwise the value is NaN.

Usage

igammac(a, x)

Value

A vector of values of a complementary incomplete gamma function.

Arguments

a

A numeric vector.

x

A nonnegative numeric vector with same length as a.

See Also

igamma()

Examples

Run this code
igammac(1, 1)

Run the code above in your browser using DataLab