Learn R Programming

dsdp (version 0.1.1)

mixExpGammaHist: Dataset of Mixture of Exponential Distribution and Gamma Distribution: Histogram Version

Description

Dataset of mixture of exponential distribution and gamma distribution, histogram version, whose density is: $$0.2(2 e^{-2x}) + 0.8 \frac{x^3}{3!}e^{-x}.$$

Usage

mixExpGammaHist

Arguments

Format

A list of numeric vectors of Mixture of Exponential and Gamma distribution Model.

n200

A numeric vector with 200 elements.

n200p

Histogram sample data with 25 bins.

n200f

Histogram frequency data with 25 bins.

n400

A numeric vector with 400 elements.

n400p

Histogram sample data with 50 bins.

n400f

Histogram frequency data with 50 bins.

n800

A numeric vector with 800 elements.

n800p

Histogram sample data with 100 bins.

n800f

Histogram frequency data with 100 bins.