Learn R Programming

dsdp (version 0.1.1)

summary.expmodel: Summary of Exponential-based expmodel object.

Description

Summary of expmodel object, including a mean and quantiles. If some estimation has done, also print out estimates, up to nmax number of them.

Usage

# S3 method for expmodel
summary(object, nmax = 10, estonly = FALSE, ...)

Value

None.

Arguments

object

expmodel object.

nmax

A number of estimates to show in the summary. The default is 10.

estonly

Show only the results of estimates. The default value is FALSE.

...

Arguments to be passed to or from other methods.

See Also

expmodel() plot.expmodel() estimate.expmodel()

Examples

Run this code
## Create expmodel object from a data set mixexpgamma$n200
emodel <- expmodel(mixexpgamma$n200)
## Print a summary of an object
summary(emodel)

Run the code above in your browser using DataLab