powered by
expmodel
Summary of expmodel object, including a mean and quantiles. If some estimation has done, also print out estimates, up to nmax number of them.
nmax
# S3 method for expmodel summary(object, nmax = 10, estonly = FALSE, ...)
None.
expmodel object.
A number of estimates to show in the summary. The default is 10.
Show only the results of estimates. The default value is FALSE.
FALSE
Arguments to be passed to or from other methods.
expmodel() plot.expmodel() estimate.expmodel()
expmodel()
plot.expmodel()
estimate.expmodel()
## Create expmodel object from a data set mixexpgamma$n200 emodel <- expmodel(mixexpgamma$n200) ## Print a summary of an object summary(emodel)
Run the code above in your browser using DataLab